@@ -1,8 +1,11 @@
 from __future__ import annotations
-from xdsl.ir import *
-from xdsl.irdl import *
-from xdsl.util import *
+from typing import List, Union
+from dataclasses import dataclass
+
 from xdsl.dialects.builtin import IntegerType
+from xdsl.ir import MLContext, SSAValue
+from xdsl.irdl import (irdl_op_definition, VarOperandDef, AnyAttr, Block,
+                       Operation, OperandDef, AttrSizedOperandSegments)
 
 
 @dataclass
