@@ -1,5 +1,11 @@
 from __future__ import annotations
-from xdsl.dialects.builtin import *
+from xdsl.ir import MLContext
+from xdsl.irdl import (VarOperandDef, irdl_op_definition, Attribute,
+                       VarResultDef, OperandDef, SSAValue, Operation,
+                       RegionDef, Region, Block, AnyAttr)
+from xdsl.dialects.builtin import IntegerType
+from dataclasses import dataclass
+from typing import List
 
 
 @dataclass
